@@ -441,6 +441,10 @@ var availableTests = [
                 type: chrome.autofillPrivate.FieldType.ALTERNATIVE_FULL_NAME,
                 value: ALTERNATIVE_FULL_NAME
               },
+              {
+                type: chrome.autofillPrivate.FieldType.ADDRESS_HOME_COUNTRY,
+                value: "JP"
+              }
             ],
           });
           // Alternative name set with a separator. Metric is emitted.
@@ -451,6 +455,10 @@ var availableTests = [
                 type: chrome.autofillPrivate.FieldType.ALTERNATIVE_FULL_NAME,
                 value: ALTERNATIVE_FULL_NAME_SEPARATOR
               },
+              {
+                type: chrome.autofillPrivate.FieldType.ADDRESS_HOME_COUNTRY,
+                value: "JP"
+              }
             ],
           });
         }));
