@@ -2542,10 +2542,6 @@ suite('AppTest', () => {
       const pluralStringProxy = new TestPluralStringProxy();
       PluralStringProxyImpl.setInstance(pluralStringProxy);
 
-      loadTimeData.overrideValues({
-        'comparisonTableListEnabled': true,
-      });
-
       shoppingServiceApi.setResultFor(
           'getAllProductSpecificationsSets', Promise.resolve({
             sets: SPECS_SETS,
@@ -2565,18 +2561,6 @@ suite('AppTest', () => {
           });
     });
 
-    test('list does not appear when the feature is off', async () => {
-      loadTimeData.overrideValues({
-        'comparisonTableListEnabled': false,
-      });
-
-      const appElement = await createAppElement();
-      await microtasksFinished();
-
-      const listElement = appElement.$.comparisonTableList;
-      assertFalse(isVisible(listElement));
-    });
-
     test('list is hidden if there are no comparison tables', async () => {
       shoppingServiceApi.setResultFor(
           'getAllProductSpecificationsSets', Promise.resolve({sets: []}));
