@@ -7,6 +7,7 @@
 import type {AccountStorageEnabledStateChangedListener, BlockedSite, BlockedSitesListChangedListener, CredentialsChangedListener, PasswordCheckInteraction, PasswordCheckStatusChangedListener, PasswordManagerAuthTimeoutListener, PasswordManagerProxy, PasswordsFileExportProgressListener, PasswordViewPageInteractions, ShouldShowAccountStorageToggleChangedListener} from 'chrome://password-manager/password_manager.js';
 import {TestBrowserProxy} from 'chrome://webui-test/test_browser_proxy.js';
 
+import type {ActorLoginPermission} from './password_manager.mojom-webui.js';
 import {makeFamilyFetchResults, makePasswordCheckStatus} from './test_util.js';
 
 /**
@@ -16,6 +17,7 @@ export class TestPasswordManagerProxy extends TestBrowserProxy implements
     PasswordManagerProxy {
   data: {
     blockedSites: BlockedSite[],
+    actorLoginPermissions: ActorLoginPermission[],
     checkStatus: chrome.passwordsPrivate.PasswordCheckStatus,
     credentialWithReusedPassword: chrome.passwordsPrivate.PasswordUiEntryList[],
     familyFetchResults: chrome.passwordsPrivate.FamilyFetchResults,
@@ -72,6 +74,7 @@ export class TestPasswordManagerProxy extends TestBrowserProxy implements
       'exportPasswords',
       'extendAuthValidity',
       'fetchFamilyMembers',
+      'getActorLoginPermissions',
       'getBlockedSitesList',
       'getCredentialGroups',
       'getCredentialsWithReusedPassword',
@@ -96,6 +99,7 @@ export class TestPasswordManagerProxy extends TestBrowserProxy implements
       'requestExportProgressStatus',
       'requestPlaintextPassword',
       'resetImporter',
+      'revokeActorLoginPermission',
       'sharePassword',
       'showAddShortcutDialog',
       'showExportedFileInShell',
@@ -108,6 +112,7 @@ export class TestPasswordManagerProxy extends TestBrowserProxy implements
     // Set these to have non-empty data.
     this.data = {
       blockedSites: [],
+      actorLoginPermissions: [],
       checkStatus: makePasswordCheckStatus({}),
       credentialWithReusedPassword: [],
       familyFetchResults: makeFamilyFetchResults(),
@@ -465,4 +470,15 @@ export class TestPasswordManagerProxy extends TestBrowserProxy implements
 
     return Promise.reject(new Error());
   }
+
+  getActorLoginPermissions() {
+    this.methodCalled('getActorLoginPermissions');
+    return Promise.resolve(this.data.actorLoginPermissions.slice());
+  }
+
+  revokeActorLoginPermission(site: ActorLoginPermission) {
+    this.methodCalled('revokeActorLoginPermission', site);
+    this.data.actorLoginPermissions = this.data.actorLoginPermissions.filter(
+        s => !(s.url.link === site.url.link && s.username === site.username));
+  }
 }
