@@ -9,7 +9,7 @@ import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min
 import type {SettingsPrivacyGuideDialogElement, SettingsPrivacyGuidePageElement} from 'chrome://settings/lazy_load.js';
 import {ContentSetting, CookieControlsMode, PrivacyGuideStep, SafeBrowsingSetting, ThirdPartyCookieBlockingSetting} from 'chrome://settings/lazy_load.js';
 import type {SettingsPrefsElement, SyncStatus} from 'chrome://settings/settings.js';
-import {HatsBrowserProxyImpl, TrustSafetyInteraction, CrSettingsPrefs, MetricsBrowserProxyImpl, PrivacyGuideStepsEligibleAndReached, PrivacyGuideBrowserProxyImpl, PrivacyGuideInteractions, resetRouterForTesting, Router, routes, StatusAction, SyncBrowserProxyImpl} from 'chrome://settings/settings.js';
+import {HatsBrowserProxyImpl, TrustSafetyInteraction, CrSettingsPrefs, MetricsBrowserProxyImpl, PrivacyGuideStepsEligibleAndReached, PrivacyGuideBrowserProxyImpl, PrivacyGuideInteractions, resetRouterForTesting, Router, routes, SignedInState, StatusAction, SyncBrowserProxyImpl} from 'chrome://settings/settings.js';
 import {assertEquals, assertFalse, assertTrue} from 'chrome://webui-test/chai_assert.js';
 import {isChildVisible, microtasksFinished} from 'chrome://webui-test/test_util.js';
 import {flushTasks} from 'chrome://webui-test/polymer_test_util.js';
@@ -270,7 +270,7 @@ suite('PrivacyGuidePage', function() {
     syncBrowserProxy = new TestSyncBrowserProxy();
     setupSync({
       syncBrowserProxy: syncBrowserProxy,
-      syncOn: true,
+      signedInState: SignedInState.SYNCING,
       syncAllDataTypes: true,
       typedUrlsSynced: true,
     });
@@ -322,7 +322,7 @@ suite('PrivacyGuidePage', function() {
 
     setupSync({
       syncBrowserProxy: syncBrowserProxy,
-      syncOn: true,
+      signedInState: SignedInState.SYNCING,
       syncAllDataTypes: true,
       typedUrlsSynced: true,
     });
@@ -492,7 +492,7 @@ suite('FlowLength', function() {
     syncBrowserProxy = new TestSyncBrowserProxy();
     setupSync({
       syncBrowserProxy: syncBrowserProxy,
-      syncOn: true,
+      signedInState: SignedInState.SYNCING,
       syncAllDataTypes: true,
       typedUrlsSynced: true,
     });
@@ -635,7 +635,7 @@ suite('MsbbCardNavigations', function() {
   test('ForwardNavigationSyncOff', async function() {
     setupSync({
       syncBrowserProxy: syncBrowserProxy,
-      syncOn: false,
+      signedInState: SignedInState.SIGNED_OUT,
       syncAllDataTypes: false,
       typedUrlsSynced: false,
     });
@@ -713,7 +713,7 @@ suite('HistorySyncCardNavigations', function() {
     // User disables sync while history sync card is shown.
     setupSync({
       syncBrowserProxy: syncBrowserProxy,
-      syncOn: false,
+      signedInState: SignedInState.SIGNED_OUT,
       syncAllDataTypes: false,
       typedUrlsSynced: false,
     });
@@ -727,7 +727,7 @@ suite('HistorySyncCardNavigations', function() {
     await navigateToStep(PrivacyGuideStep.HISTORY_SYNC);
     setupSync({
       syncBrowserProxy: syncBrowserProxy,
-      syncOn: false,
+      signedInState: SignedInState.SIGNED_OUT,
       syncAllDataTypes: false,
       typedUrlsSynced: false,
     });
@@ -752,6 +752,40 @@ suite('HistorySyncCardNavigations', function() {
         'Settings.PrivacyGuide.NextClickHistorySync',
         testMetricsBrowserProxy.getArgs('recordAction')[0]);
   });
+
+  // <if expr="not is_chromeos">
+  // ChromeOS does not have signed-in non-syncing users.
+  test('ShownForSignedInUsersWhenFlagEnabled', async function() {
+    loadTimeData.overrideValues({'replaceSyncPromosWithSignInPromos': true});
+
+    setupSync({
+      syncBrowserProxy: syncBrowserProxy,
+      signedInState: SignedInState.SIGNED_IN,
+      syncAllDataTypes: true,
+      typedUrlsSynced: true,
+    });
+
+    await navigateToStep(PrivacyGuideStep.HISTORY_SYNC);
+    assertHistorySyncCardVisible(
+        page, syncBrowserProxy, testPrivacyGuideBrowserProxy);
+  });
+
+  test('NotShownForSignedInUsersWhenFlagDisabled', async function() {
+    loadTimeData.overrideValues({'replaceSyncPromosWithSignInPromos': false});
+
+    await navigateToStep(PrivacyGuideStep.HISTORY_SYNC);
+    setupSync({
+      syncBrowserProxy: syncBrowserProxy,
+      signedInState: SignedInState.SIGNED_IN,
+      syncAllDataTypes: true,
+      typedUrlsSynced: true,
+    });
+    // The history sync card is removed/not shown anymore and the next card is
+    // shown instead.
+    assertSafeBrowsingCardVisible(
+        page, syncBrowserProxy, testPrivacyGuideBrowserProxy);
+  });
+  // </if>
 });
 
 suite('SafeBrowsingCardNavigations', function() {
@@ -813,7 +847,7 @@ suite('SafeBrowsingCardNavigations', function() {
   test('BackNavigationSyncOff', async function() {
     setupSync({
       syncBrowserProxy: syncBrowserProxy,
-      syncOn: false,
+      signedInState: SignedInState.SIGNED_OUT,
       syncAllDataTypes: false,
       typedUrlsSynced: false,
     });
@@ -1096,7 +1130,7 @@ suite('AdTopicsCardNavigations', function() {
       async function() {
         setupSync({
           syncBrowserProxy: syncBrowserProxy,
-          syncOn: false,
+          signedInState: SignedInState.SIGNED_OUT,
           syncAllDataTypes: false,
           typedUrlsSynced: false,
         });
@@ -1254,7 +1288,7 @@ suite('3pcdOff', function() {
     syncBrowserProxy = new TestSyncBrowserProxy();
     setupSync({
       syncBrowserProxy: syncBrowserProxy,
-      syncOn: true,
+      signedInState: SignedInState.SYNCING,
       syncAllDataTypes: true,
       typedUrlsSynced: true,
     });
