@@ -7,11 +7,15 @@
 
 import 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 
-import {ContentController, HIGHLIGHTED_LINK_CLASS, NodeStore, previousReadHighlightClass, ReadAloudNode, SpeechBrowserProxyImpl, SpeechController} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
-import {assertArrayEquals, assertEquals, assertFalse, assertTrue} from 'chrome-untrusted://webui-test/chai_assert.js';
+import {ContentController, ContentType, HIGHLIGHTED_LINK_CLASS, LOG_EMPTY_DELAY_MS, MIN_MS_TO_READ, NodeStore, previousReadHighlightClass, ReadAloudNode, SpeechBrowserProxyImpl, SpeechController} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
+import type {ContentListener} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
+import {assertArrayEquals, assertEquals, assertFalse, assertNotEquals, assertStringContains, assertTrue} from 'chrome-untrusted://webui-test/chai_assert.js';
+import {MockTimer} from 'chrome-untrusted://webui-test/mock_timer.js';
 import {microtasksFinished} from 'chrome-untrusted://webui-test/test_util.js';
 
+import {mockMetrics, stubAnimationFrame} from './common.js';
 import {FakeReadingMode} from './fake_reading_mode.js';
+import type {TestMetricsBrowserProxy} from './test_metrics_browser_proxy.js';
 import {TestSpeechBrowserProxy} from './test_speech_browser_proxy.js';
 
 suite('ContentController', () => {
@@ -19,6 +23,10 @@ suite('ContentController', () => {
   let readingMode: FakeReadingMode;
   let nodeStore: NodeStore;
   let speechController: SpeechController;
+  let metrics: TestMetricsBrowserProxy;
+  let listener: ContentListener;
+  let receivedContentStateChange: boolean;
+  let receivedNewPageDrawn: boolean;
 
   setup(() => {
     // Clearing the DOM should always be done first.
@@ -26,24 +34,285 @@ suite('ContentController', () => {
     readingMode = new FakeReadingMode();
     chrome.readingMode = readingMode as unknown as typeof chrome.readingMode;
 
+    metrics = mockMetrics();
     nodeStore = new NodeStore();
     NodeStore.setInstance(nodeStore);
     SpeechBrowserProxyImpl.setInstance(new TestSpeechBrowserProxy());
     speechController = new SpeechController();
     SpeechController.setInstance(speechController);
     contentController = new ContentController();
+
+    receivedContentStateChange = false;
+    receivedNewPageDrawn = false;
+    listener = {
+      onContentStateChange() {
+        receivedContentStateChange = true;
+      },
+      onNewPageDrawn() {
+        receivedNewPageDrawn = true;
+      },
+    };
+    contentController.addListener(listener);
   });
 
-  suite('buildSubtree', () => {
-    const nodeId = 29;
+  suite('setEmpty', () => {
+    setup(() => {
+      contentController.setState(ContentType.HAS_CONTENT);
+    });
+
+    test('sets empty state', () => {
+      const emptyPath = 'empty_state.svg';
+
+      contentController.setEmpty();
+
+      const empty = contentController.getState();
+      assertTrue(contentController.isEmpty());
+      assertStringContains(empty.darkImagePath, emptyPath);
+      assertStringContains(empty.imagePath, emptyPath);
+    });
+
+    test('logs if still empty after delay', () => {
+      const mockTimer = new MockTimer();
+      mockTimer.install();
+
+      contentController.setEmpty();
+      assertTrue(contentController.isEmpty());
+      assertEquals(0, metrics.getCallCount('recordEmptyState'));
+
+      mockTimer.tick(LOG_EMPTY_DELAY_MS);
+      assertTrue(contentController.isEmpty());
+      assertEquals(1, metrics.getCallCount('recordEmptyState'));
+
+      mockTimer.uninstall();
+    });
+
+    test('does not log if not empty after delay', () => {
+      const mockTimer = new MockTimer();
+      mockTimer.install();
+
+      contentController.setEmpty();
+      assertEquals(0, metrics.getCallCount('recordEmptyState'));
+
+      contentController.setState(ContentType.HAS_CONTENT);
+      mockTimer.tick(LOG_EMPTY_DELAY_MS);
+      assertEquals(0, metrics.getCallCount('recordEmptyState'));
+
+      mockTimer.uninstall();
+    });
+
+    test('logs empty state once if still empty', () => {
+      const mockTimer = new MockTimer();
+      mockTimer.install();
+
+      contentController.setEmpty();
+      mockTimer.tick(LOG_EMPTY_DELAY_MS);
+      assertEquals(1, metrics.getCallCount('recordEmptyState'));
+      assertTrue(contentController.isEmpty());
+
+      contentController.setEmpty();
+      mockTimer.tick(LOG_EMPTY_DELAY_MS);
+      assertEquals(1, metrics.getCallCount('recordEmptyState'));
+      assertTrue(contentController.isEmpty());
+
+      mockTimer.uninstall();
+    });
+  });
+
+  test('setState notifies listeners of state change', () => {
+    contentController.setState(ContentType.HAS_CONTENT);
+    assertTrue(receivedContentStateChange);
+
+    // Don't notify a second time for the same state.
+    receivedContentStateChange = false;
+    contentController.setState(ContentType.HAS_CONTENT);
+    assertFalse(receivedContentStateChange);
+  });
+
+  test('setEmpty depends on google docs', () => {
+    chrome.readingMode.isGoogleDocs = true;
+    contentController.setEmpty();
+    const docsHeading = contentController.getState().heading;
+
+    chrome.readingMode.isGoogleDocs = false;
+    contentController.setEmpty();
+    const regularHeading = contentController.getState().heading;
+
+    assertNotEquals(docsHeading, regularHeading);
+  });
+
+  test('hasContent', () => {
+    assertFalse(contentController.hasContent());
+
+    contentController.setState(ContentType.HAS_CONTENT);
+    assertTrue(contentController.hasContent());
+
+    contentController.setState(ContentType.LOADING);
+    assertFalse(contentController.hasContent());
+
+    contentController.setEmpty();
+    assertFalse(contentController.hasContent());
+  });
+
+  test('isEmpty', () => {
+    assertTrue(contentController.isEmpty());
+
+    contentController.setState(ContentType.HAS_CONTENT);
+    assertFalse(contentController.isEmpty());
+
+    contentController.setState(ContentType.LOADING);
+    assertFalse(contentController.isEmpty());
+
+    contentController.setEmpty();
+    assertTrue(contentController.isEmpty());
+  });
+
+  test('onNodeWillBeDeleted removes node', () => {
+    const id1 = 10;
+    const id2 = 12;
+    chrome.readingMode.rootId = id2;
+    const node1 = document.createTextNode('Huntrx don\'t miss');
+    const node2 = document.createTextNode('How it\'s done done done');
+    nodeStore.setDomNode(node1, id1);
+    nodeStore.setDomNode(node2, id2);
+    contentController.setState(ContentType.HAS_CONTENT);
+
+    contentController.onNodeWillBeDeleted(id1);
+
+    assertFalse(!!nodeStore.getDomNode(id1));
+    assertTrue(contentController.hasContent());
+  });
+
+  test('onNodeWillBeDeleted shows empty if no more nodes', () => {
+    const id = 10;
+    const node = document.createTextNode('Huntrx don\'t quit');
+    chrome.readingMode.rootId = id;
+    nodeStore.setDomNode(node, id);
+    contentController.setState(ContentType.HAS_CONTENT);
+
+    contentController.onNodeWillBeDeleted(id);
+
+    assertFalse(!!nodeStore.getDomNode(id));
+    assertFalse(contentController.hasContent());
+    assertTrue(contentController.isEmpty());
+  });
+
+  suite('updateContent', () => {
+    const rootId = 29;
+    let node: HTMLElement;
+
+    setup(() => {
+      node = document.createElement('p');
+      const text = document.createTextNode('One swing ahead of the sword');
+      node.appendChild(text);
+      document.body.appendChild(node);
+      chrome.readingMode.rootId = rootId;
+    });
+
+    test('logs speech stop if called while speech active', async () => {
+      speechController.onPlayPauseToggle(node);
+
+      contentController.updateContent();
+
+      assertEquals(
+          chrome.readingMode.unexpectedUpdateContentStopSource,
+          await metrics.whenCalled('recordSpeechStopSource'));
+    });
+
+    test('does not crash with no root', () => {
+      chrome.readingMode.rootId = 0;
+      assertFalse(!!contentController.updateContent());
+    });
+
+    test('hides loading page', () => {
+      readingMode.getHtmlTag = () => '';
+      readingMode.getTextContent = () => 'but I bite';
+      contentController.setState(ContentType.LOADING);
+
+      const root = contentController.updateContent();
+
+      assertTrue(!!root);
+      assertTrue(contentController.hasContent());
+      assertFalse(contentController.isEmpty());
+    });
+
+    test('sets empty if no content', () => {
+      contentController.setState(ContentType.LOADING);
+
+      const root = contentController.updateContent();
+
+      assertFalse(!!root);
+      assertFalse(contentController.hasContent());
+      assertTrue(contentController.isEmpty());
+    });
+
+    test('logs new page with new tree', () => {
+      readingMode.getHtmlTag = () => '';
+      readingMode.getTextContent = () => 'okay like I know I ramble';
+
+      contentController.updateContent();
+      contentController.updateContent();
+      assertEquals(1, metrics.getCallCount('recordNewPage'));
+
+      chrome.readingMode.rootId = rootId + 1;
+      contentController.updateContent();
+
+      assertEquals(2, metrics.getCallCount('recordNewPage'));
+    });
+
+    test('loads images with flag enabled', () => {
+      const imgId1 = 89;
+      const imgId2 = 88;
+      readingMode.imagesFeatureEnabled = true;
+      readingMode.getHtmlTag = () => '';
+      readingMode.getTextContent = () => 'okay like I know I ramble';
+
+      readingMode.imagesEnabled = true;
+      nodeStore.addImageToFetch(imgId1);
+      contentController.updateContent();
+
+      readingMode.imagesEnabled = false;
+      nodeStore.addImageToFetch(imgId2);
+      contentController.updateContent();
+
+      assertArrayEquals([imgId1, imgId2], readingMode.fetchedImages);
+    });
+
+    test('notifies listeners of new page drawn', () => {
+      readingMode.getHtmlTag = () => '';
+      readingMode.getTextContent = () => 'I go Rambo';
+      stubAnimationFrame();
+
+      contentController.updateContent();
+
+      assertTrue(receivedNewPageDrawn);
+    });
+
+    test('estimates words seen after draw', () => {
+      readingMode.getHtmlTag = () => '';
+      readingMode.getTextContent = () => 'full of venom';
+      stubAnimationFrame();
+      const mockTimer = new MockTimer();
+      mockTimer.install();
+      let sentWordsSeen = false;
+      readingMode.updateWordsSeen = () => {
+        sentWordsSeen = true;
+      };
+
+      contentController.updateContent();
+      mockTimer.tick(MIN_MS_TO_READ);
+      mockTimer.uninstall();
+
+      assertTrue(sentWordsSeen);
+    });
 
     test('builds a simple text node', () => {
       const text = 'Knockin you out like a lullaby';
       readingMode.getHtmlTag = () => '';
       readingMode.getTextContent = () => text;
 
-      const root = contentController.buildSubtree(nodeId);
+      const root = contentController.updateContent();
 
+      assertTrue(!!root);
       assertEquals(Node.TEXT_NODE, root.nodeType);
       assertEquals(text, root.textContent);
     });
@@ -54,8 +323,9 @@ suite('ContentController', () => {
       readingMode.getTextContent = () => text;
       readingMode.shouldBold = () => true;
 
-      const root = contentController.buildSubtree(nodeId);
+      const root = contentController.updateContent();
 
+      assertTrue(!!root);
       assertEquals('B', root.nodeName);
       assertEquals(text, root.textContent);
     });
@@ -66,7 +336,7 @@ suite('ContentController', () => {
       readingMode.getTextContent = () => text;
       readingMode.isOverline = () => true;
 
-      const root = contentController.buildSubtree(nodeId);
+      const root = contentController.updateContent();
 
       assertTrue(root instanceof HTMLSpanElement);
       assertEquals(text, root.textContent);
@@ -87,56 +357,56 @@ suite('ContentController', () => {
       readingMode.getTextContent = (id) => {
         return id === childId ? text : '';
       };
+      chrome.readingMode.rootId = parentId;
 
-      const root = contentController.buildSubtree(parentId);
+      const root = contentController.updateContent();
 
+      assertTrue(!!root);
       assertEquals('P', root.nodeName);
       assertTrue(!!root.firstChild);
       assertEquals(text, root.textContent);
     });
 
     test('builds a link as an <a> tag when links are shown', () => {
+      const childId = 65;
       const url = 'https://www.google.com/';
       chrome.readingMode.linksEnabled = true;
-      readingMode.getHtmlTag = () => 'a';
+      readingMode.getHtmlTag = (id) => {
+        return id === childId ? '' : 'a';
+      };
       readingMode.getUrl = () => url;
+      readingMode.getTextContent = () => url;
       let clicked = false;
       readingMode.onLinkClicked = () => {
         clicked = true;
       };
+      readingMode.getChildren = (id) => {
+        return id === childId ? [] : [childId];
+      };
 
-      const root = contentController.buildSubtree(nodeId);
+      const root = contentController.updateContent();
 
-      assertTrue(root instanceof HTMLAnchorElement);
+      assertTrue(root instanceof HTMLAnchorElement, 'instance');
       assertEquals(url, root.href);
-      assertTrue(!!root.onclick);
+      assertTrue(!!root.onclick, 'onclick');
       root.onclick(new MouseEvent('type'));
-      assertTrue(clicked);
+      assertTrue(clicked, 'clicked');
     });
 
     test('builds a link as a <span> tag when links are hidden', () => {
+      const childId = 71;
       const url = 'https://www.relsilicon.com/';
       chrome.readingMode.linksEnabled = false;
-      readingMode.getHtmlTag = () => 'a';
+      readingMode.getHtmlTag = (id) => {
+        return id === childId ? '' : 'a';
+      };
       readingMode.getUrl = () => url;
+      readingMode.getTextContent = () => url;
+      readingMode.getChildren = (id) => {
+        return id === childId ? [] : [childId];
+      };
 
-      const root = contentController.buildSubtree(nodeId);
-
-      assertTrue(root instanceof HTMLSpanElement);
-      assertEquals(url, root.dataset['link']);
-      assertFalse(!!root.getAttribute('href'));
-    });
-
-    test('builds a link as a <span> tag when speech is playing', () => {
-      const url = 'https://www.usecheeky.com/';
-      chrome.readingMode.linksEnabled = true;
-      const element = document.createElement('p');
-      element.textContent = 'Cause I\'m gonna show you';
-      speechController.onPlayPauseToggle(null, element);
-      readingMode.getHtmlTag = () => 'a';
-      readingMode.getUrl = () => url;
-
-      const root = contentController.buildSubtree(nodeId);
+      const root = contentController.updateContent();
 
       assertTrue(root instanceof HTMLSpanElement);
       assertEquals(url, root.dataset['link']);
@@ -149,14 +419,14 @@ suite('ContentController', () => {
       readingMode.getHtmlTag = () => 'img';
       readingMode.getAltText = () => altText;
 
-      const root = contentController.buildSubtree(nodeId);
+      const root = contentController.updateContent();
 
       assertTrue(root instanceof HTMLCanvasElement);
       assertEquals(altText, root.getAttribute('alt'));
       assertEquals('', root.style.display);
       assertTrue(nodeStore.hasImagesToFetch());
       nodeStore.fetchImages();
-      assertArrayEquals([nodeId], readingMode.fetchedImages);
+      assertArrayEquals([rootId], readingMode.fetchedImages);
     });
 
     test('builds a video as a <canvas> tag', () => {
@@ -165,39 +435,62 @@ suite('ContentController', () => {
       readingMode.getHtmlTag = () => 'video';
       readingMode.getAltText = () => altText;
 
-      const root = contentController.buildSubtree(nodeId);
+      const root = contentController.updateContent();
 
       assertTrue(root instanceof HTMLCanvasElement);
       assertEquals(altText, root.getAttribute('alt'));
       assertEquals('', root.style.display);
       assertTrue(nodeStore.hasImagesToFetch());
       nodeStore.fetchImages();
-      assertArrayEquals([nodeId], readingMode.fetchedImages);
+      assertArrayEquals([rootId], readingMode.fetchedImages);
     });
 
     test('sets text direction', () => {
-      readingMode.getHtmlTag = () => 'p';
+      const childId = 70;
+      readingMode.getHtmlTag = (id) => {
+        return id === childId ? '' : 'p';
+      };
       readingMode.getTextDirection = () => 'rtl';
+      readingMode.getTextContent = () => 'spittin facts';
+      readingMode.getChildren = (id) => {
+        return id === childId ? [] : [childId];
+      };
 
-      const root = contentController.buildSubtree(nodeId);
+      const root = contentController.updateContent();
 
       assertTrue(root instanceof HTMLParagraphElement);
       assertEquals('rtl', root.getAttribute('dir'));
     });
 
     test('sets the language', () => {
-      readingMode.getHtmlTag = () => 'p';
+      const childId = 70;
+      readingMode.getHtmlTag = (id) => {
+        return id === childId ? '' : 'p';
+      };
       readingMode.getLanguage = () => 'ko';
+      readingMode.getTextContent = () => 'you know that\'s';
+      readingMode.getChildren = (id) => {
+        return id === childId ? [] : [childId];
+      };
 
-      const root = contentController.buildSubtree(nodeId);
+      const root = contentController.updateContent();
 
       assertTrue(root instanceof HTMLParagraphElement);
       assertEquals('ko', root.getAttribute('lang'));
     });
 
     test('builds details as a div', () => {
-      readingMode.getHtmlTag = () => 'details';
-      const root = contentController.buildSubtree(nodeId);
+      const childId = 67;
+      readingMode.getHtmlTag = (id) => {
+        return id === childId ? '' : 'details';
+      };
+      readingMode.getChildren = (id) => {
+        return id === childId ? [] : [childId];
+      };
+      readingMode.getTextContent = () => 'I don\'t talk';
+
+      const root = contentController.updateContent();
+
       assertTrue(root instanceof HTMLDivElement);
     });
   });
@@ -220,7 +513,8 @@ suite('ContentController', () => {
 
     test('does nothing if no content', () => {
       chrome.readingMode.linksEnabled = false;
-      contentController.updateLinks(false, shadowRoot);
+      contentController.setState(ContentType.NO_CONTENT);
+      contentController.updateLinks(shadowRoot);
       assertFalse(!!shadowRoot.firstChild);
     });
 
@@ -229,7 +523,8 @@ suite('ContentController', () => {
       shadowRoot.appendChild(link);
       nodeStore.setDomNode(link, linkId);
 
-      contentController.updateLinks(true, shadowRoot);
+      contentController.setState(ContentType.HAS_CONTENT);
+      contentController.updateLinks(shadowRoot);
 
       assertFalse(!!shadowRoot.querySelector('a'));
       const span = shadowRoot.querySelector('span[data-link]');
@@ -244,7 +539,8 @@ suite('ContentController', () => {
       nodeStore.setDomNode(span, linkId);
       chrome.readingMode.linksEnabled = true;
 
-      contentController.updateLinks(true, shadowRoot);
+      contentController.setState(ContentType.HAS_CONTENT);
+      contentController.updateLinks(shadowRoot);
 
       assertFalse(!!shadowRoot.querySelector('span[data-link]'));
       const link = shadowRoot.querySelector('a');
@@ -260,7 +556,8 @@ suite('ContentController', () => {
       nodeStore.setDomNode(link, linkId);
       chrome.readingMode.linksEnabled = false;
 
-      contentController.updateLinks(true, shadowRoot);
+      contentController.setState(ContentType.HAS_CONTENT);
+      contentController.updateLinks(shadowRoot);
 
       const newInnerSpan = shadowRoot.querySelector('span[data-link] span');
       assertTrue(!!newInnerSpan);
@@ -278,7 +575,8 @@ suite('ContentController', () => {
       nodeStore.setDomNode(outerSpan, linkId);
       chrome.readingMode.linksEnabled = true;
 
-      contentController.updateLinks(true, shadowRoot);
+      contentController.setState(ContentType.HAS_CONTENT);
+      contentController.updateLinks(shadowRoot);
 
       const newInnerSpan = shadowRoot.querySelector('a span');
       assertTrue(!!newInnerSpan);
@@ -296,7 +594,8 @@ suite('ContentController', () => {
           nodeStore.setDomNode(link, linkId);
           chrome.readingMode.linksEnabled = false;
 
-          contentController.updateLinks(true, shadowRoot);
+          contentController.setState(ContentType.HAS_CONTENT);
+          contentController.updateLinks(shadowRoot);
 
           const newInnerSpan = shadowRoot.querySelector('span[data-link] span');
           assertTrue(!!newInnerSpan);
@@ -317,7 +616,8 @@ suite('ContentController', () => {
           nodeStore.setDomNode(outerSpan, linkId);
           chrome.readingMode.linksEnabled = true;
 
-          contentController.updateLinks(true, shadowRoot);
+          contentController.setState(ContentType.HAS_CONTENT);
+          contentController.updateLinks(shadowRoot);
 
           const newInnerSpan = shadowRoot.querySelector('a span');
           assertTrue(!!newInnerSpan);
@@ -338,7 +638,8 @@ suite('ContentController', () => {
           chrome.readingMode.linksEnabled = false;
 
           contentController.onSelectionChange(shadowRoot);
-          contentController.updateLinks(true, shadowRoot);
+          contentController.setState(ContentType.HAS_CONTENT);
+          contentController.updateLinks(shadowRoot);
 
           const newInnerSpan = shadowRoot.querySelector('span[data-link] span');
           assertTrue(!!newInnerSpan);
@@ -451,8 +752,9 @@ suite('ContentController', () => {
     test('hides images and associated text nodes when disabled', async () => {
       chrome.readingMode.imagesFeatureEnabled = true;
       chrome.readingMode.imagesEnabled = false;
+      contentController.setState(ContentType.HAS_CONTENT);
 
-      contentController.updateImages(true, shadowRoot);
+      contentController.updateImages(shadowRoot);
       await microtasksFinished();
 
       assertEquals('none', canvas.style.display);
@@ -467,8 +769,9 @@ suite('ContentController', () => {
       nodeStore.hideImageNode(textId);
       canvas.style.display = 'none';
       figure.style.display = 'none';
+      contentController.setState(ContentType.HAS_CONTENT);
 
-      contentController.updateImages(true, shadowRoot);
+      contentController.updateImages(shadowRoot);
       await microtasksFinished();
 
       assertEquals('', canvas.style.display);
